@@ -1,7 +1,7 @@
 package List::Lazy;
 our $AUTHORITY = 'cpan:YANICK'; 
 # ABSTRACT: Generate lists lazily
-$List::Lazy::VERSION = '0.0.1';
+$List::Lazy::VERSION = '0.1.0';
 
 
 
@@ -21,6 +21,16 @@ use Carp;
 
 extends 'Exporter::Tiny';
 
+sub _exporter_validate_opts {
+    my $into = $_[1]->{into};
+    eval qq{
+        *${into}::a = *::a;
+        *${into}::b = *::b;
+        1;
+    } or die $@;
+}
+
+
 our @EXPORT_OK = qw/ lazy_list lazy_range lazy_fixed_list /;
 
 sub lazy_list :prototype(&@) ($generator,$state=undef) {
@@ -120,12 +130,10 @@ sub reduce($self,$reducer,$reduced=undef) {
 }
 
 sub map($self,$map) {
-    my $gen = $self->generator;
-
     return List::Lazy->new(
-        state => clone( $self->state ),
+        state => $self->_clone,
         generator => sub {
-            while( my @next = $gen->() ) {
+            while( my @next = $_->next ) {
                 @next = map { $map->() } @next;
                 return @next if @next;
             }
@@ -138,7 +146,8 @@ sub grep($self,$filter) {
     $self->map(sub{ $filter->() ? $_ : () })
 }
 
-sub spy($self,$sub) {
+sub spy($self,$sub=undef) {
+    $sub ||= sub { carp $_ };
     $self->map(sub{ $sub->(); $_ } ); 
 }
 
@@ -202,7 +211,7 @@ List::Lazy - Generate lists lazily
 
 =head1 VERSION
 
-version 0.0.1
+version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -298,10 +307,10 @@ that many items left). C<$num> defaults to C<1>.
     my $value = $list->reduce( $reducing_sub, $initial_value );
 
 Iterates through the list and reduces its values via the C<$reducing_sub>, which
-will be passed the cumulative value and the next item via C<$::a> and C<$::b>. 
+will be passed the cumulative value and the next item via C<$a> and C<$b>. 
 If C<$initial_value> is not given, it defaults to the first element of the list.
 
-    my $sum = lazy_range( 1, 100 )->reduce( sub { $::a + $::b } );
+    my $sum = lazy_range( 1, 100 )->reduce( sub { $a + $b } );
 
 =head2 map
 
@@ -331,6 +340,15 @@ from the new list won't affect the original list.
 
     my $odd = ( lazy_range 1, 100 )->grep( sub { $_ % 2 } );
 
+=head2 spy
+
+    my $new_list = $list->spy( $sub );
+
+Creates a new list that will execute the spy C<$sub> for
+every value it sees (with the value assigned to C<$_>). 
+
+If C<$sub> is not given, it'll C<carp> the values.
+
 =head2 until
 
     my $new_list = $list->until( $condition );
